Mnemonics class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

entropyToMnemonic(Entropye entropy) → Future<String>
generate mnemonic from entropy
entropyToSeed(Entropye entropy) → Future<SeedBytes>
generate seed from entropy
mnemonicToEntropy(String mnemonic) → Future<Entropye>
generate entropy from mnemonic