Program class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

curry({required List<Program> args}) → Future<Program>
Curry the program with args
disassemble() → Future<String>
convert to source code
hash() → Future<Puzzlehash>
sinonim of treeHash
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(List<Program> args) → Future<Output>
Run the program with args
runWithCmdCommands(Program args) → Future<Output>
Run the program with args using the clvm tools commands
serializeToBytes() → Future<Bytes>
serialize program to bytes
serializeToHex() → Future<String>
serialize program to hex
toBytes() → Future<Bytes>
toSource() → Future<String>
parse program to source code
toString() → String
A string representation of this object.
inherited
treeHash() → Future<Puzzlehash>
obtain the program hash
uncurry() → Future<UncurriedProgram>
uncurry the program

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

deserializeBytes(List<int> bytes) → Program
parse bytes to program
deserializedHexWithNative(String hex) → Future<Program>
parse hex to program
deserializeHex(String hex) → Program
parse hex to program
fromAtomBytes(Bytes atomBytes) → Future<Program>
Atom program from bytes
fromInt(int number) → Program
Program from int value
list(List<Program> list) → Future<Program>
Program from list
parse(String strProgram) → Program
Program from source code
serializedFromBytes(Bytes bytes) → Future<Program>
Program from bytes